@@ -1791,27 +1791,30 @@ class SavingPlanUsageDetail(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _SpType: 节省计划类型
+        :param _SpId: <p>节省计划资源id</p>
+        :type SpId: str
+        :param _SpType: <p>节省计划类型</p>
         :type SpType: str
-        :param _Status: 节省计划状态
+        :param _Status: <p>节省计划状态</p>枚举值：<ul><li> 1：  生效</li><li> 2： 失效 </li><li> 3： 作废</li></ul>
         :type Status: int
-        :param _DeductAmount: 累计抵扣的金额（单位：元）
+        :param _DeductAmount: <p>累计抵扣的金额（单位：元）</p>
         :type DeductAmount: str
-        :param _PromiseAmount: 累计承诺消费金额（单位：元）
+        :param _PromiseAmount: <p>累计承诺消费金额（单位：元）</p>
         :type PromiseAmount: str
-        :param _NetSavings: 累计净节省金额（单位：元）
+        :param _NetSavings: <p>累计净节省金额（单位：元）</p>
         :type NetSavings: str
-        :param _UtilizationRate: 使用率
+        :param _UtilizationRate: <p>使用率</p>
         :type UtilizationRate: float
-        :param _LossAmount: 累计流失金额（单位：元）
+        :param _LossAmount: <p>累计流失金额（单位：元）</p>
         :type LossAmount: str
-        :param _DosageAmount: 累计按量计费预期金额（单位：元）
+        :param _DosageAmount: <p>累计按量计费预期金额（单位：元）</p>
         :type DosageAmount: str
-        :param _CostAmount: 累计成本金额（单位：元）
+        :param _CostAmount: <p>累计成本金额（单位：元）</p>
         :type CostAmount: str
-        :param _Region: 地域
+        :param _Region: <p>地域</p>
         :type Region: list of str
         """
+        self._SpId = None
         self._SpType = None
         self._Status = None
         self._DeductAmount = None
@@ -1823,9 +1826,20 @@ class SavingPlanUsageDetail(AbstractModel):
         self._CostAmount = None
         self._Region = None
 
+    @property
+    def SpId(self):
+        r"""<p>节省计划资源id</p>
+        :rtype: str
+        """
+        return self._SpId
+
+    @SpId.setter
+    def SpId(self, SpId):
+        self._SpId = SpId
+
     @property
     def SpType(self):
-        r"""节省计划类型
+        r"""<p>节省计划类型</p>
         :rtype: str
         """
         return self._SpType
@@ -1836,7 +1850,7 @@ class SavingPlanUsageDetail(AbstractModel):
 
     @property
     def Status(self):
-        r"""节省计划状态
+        r"""<p>节省计划状态</p>枚举值：<ul><li> 1：  生效</li><li> 2： 失效 </li><li> 3： 作废</li></ul>
         :rtype: int
         """
         return self._Status
@@ -1847,7 +1861,7 @@ class SavingPlanUsageDetail(AbstractModel):
 
     @property
     def DeductAmount(self):
-        r"""累计抵扣的金额（单位：元）
+        r"""<p>累计抵扣的金额（单位：元）</p>
         :rtype: str
         """
         return self._DeductAmount
@@ -1858,7 +1872,7 @@ class SavingPlanUsageDetail(AbstractModel):
 
     @property
     def PromiseAmount(self):
-        r"""累计承诺消费金额（单位：元）
+        r"""<p>累计承诺消费金额（单位：元）</p>
         :rtype: str
         """
         return self._PromiseAmount
@@ -1869,7 +1883,7 @@ class SavingPlanUsageDetail(AbstractModel):
 
     @property
     def NetSavings(self):
-        r"""累计净节省金额（单位：元）
+        r"""<p>累计净节省金额（单位：元）</p>
         :rtype: str
         """
         return self._NetSavings
@@ -1880,7 +1894,7 @@ class SavingPlanUsageDetail(AbstractModel):
 
     @property
     def UtilizationRate(self):
-        r"""使用率
+        r"""<p>使用率</p>
         :rtype: float
         """
         return self._UtilizationRate
@@ -1891,7 +1905,7 @@ class SavingPlanUsageDetail(AbstractModel):
 
     @property
     def LossAmount(self):
-        r"""累计流失金额（单位：元）
+        r"""<p>累计流失金额（单位：元）</p>
         :rtype: str
         """
         return self._LossAmount
@@ -1902,7 +1916,7 @@ class SavingPlanUsageDetail(AbstractModel):
 
     @property
     def DosageAmount(self):
-        r"""累计按量计费预期金额（单位：元）
+        r"""<p>累计按量计费预期金额（单位：元）</p>
         :rtype: str
         """
         return self._DosageAmount
@@ -1913,7 +1927,7 @@ class SavingPlanUsageDetail(AbstractModel):
 
     @property
     def CostAmount(self):
-        r"""累计成本金额（单位：元）
+        r"""<p>累计成本金额（单位：元）</p>
         :rtype: str
         """
         return self._CostAmount
@@ -1924,7 +1938,7 @@ class SavingPlanUsageDetail(AbstractModel):
 
     @property
     def Region(self):
-        r"""地域
+        r"""<p>地域</p>
         :rtype: list of str
         """
         return self._Region
@@ -1935,6 +1949,7 @@ class SavingPlanUsageDetail(AbstractModel):
 
 
     def _deserialize(self, params):
+        self._SpId = params.get("SpId")
         self._SpType = params.get("SpType")
         self._Status = params.get("Status")
         self._DeductAmount = params.get("DeductAmount")
